Module remote

Module remote 

Remote management query helper.

Connects as a shared client, creates a link to a remote management destination, sends a request, and returns the response data.

Structs

RemoteQueryResult
Result from a remote management query.

Functions

parse_hex_hash
Parse a 32-hex-char destination hash.
remote_query
Perform a remote management query.