Remote management query helper.
Connects as a shared client, creates a link to a remote management destination, sends a request, and returns the response data.
Structs
- Remote
Query Result - Result from a remote management query.
Functions
- parse_
hex_ hash - Parse a 32-hex-char destination hash.
- remote_
query - Perform a remote management query.